# -*- coding: utf-8 -*-

from rest_framework import generics
from rest_framework.permissions import AllowAny

from thux.api.views import QuerysetMixin

from .. import models
from . import serializers


class SliderList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (AllowAny,)
    queryset = models.Slider.objects.filter(status=1)
    serializer_class = serializers.SliderSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(SliderList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class PictureList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (AllowAny,)
    queryset = models.Picture.objects.filter(status=1, slider__status=1)
    serializer_class = serializers.PictureSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(PictureList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset
