# coding: utf-8
from __future__ import unicode_literals
from six import python_2_unicode_compatible

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from easy_thumbnails.files import get_thumbnailer
from image_cropping import ImageRatioField

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel
from thux.i18n.models import Language


@python_2_unicode_compatible
class Slider(DateModel, UserModel, StatusModel, OrderedModel):
    name = models.CharField(
        max_length=255,
        unique=True,
        db_index=True,
        verbose_name=_('name')
    )
    slug = models.SlugField(
        max_length=255,
        unique=True,
        db_index=True,
        verbose_name=_('slug'),
    )
    language = models.ForeignKey(
        Language,
        blank=True, null=True,
        db_index=True,
        verbose_name=_('language'),
        help_text=_('language'),
    )

    class Meta:
        verbose_name = _('slider')
        verbose_name_plural = _('sliders')
        ordering = ['ordering', 'name']

    def __str__(self):
        return self.name


@python_2_unicode_compatible
class Picture(DateModel, UserModel, StatusModel, OrderedModel):
    slider = models.ForeignKey(
        Slider,
        related_name='pictures',
        verbose_name=_('slider')
    )
    title = models.CharField(
        max_length=200,
        db_index=True,
        verbose_name=_('title')
    )
    abstract = models.TextField(
        verbose_name=_('abstract'),
        blank=True
    )
    image = models.ImageField(
        upload_to=settings.SLIDER_PICTURE_FILE_UPLOAD_TO,
        max_length=150,
        verbose_name=_('image'),
    )
    cropping = ImageRatioField(
        'image',
        settings.SLIDER_PICTURE_CROPPING_SIZE,
        verbose_name=_('square cropping')
    )
    link = models.URLField(
        verbose_name=_('link'),
        max_length=255,
        blank=True,
    )

    class Meta:
        verbose_name = _('picture')
        verbose_name_plural = _('pictures')
        ordering = ['ordering', 'title', 'slider']

    def __str__(self):
        return self.title

    def get_cropped_picture(self):
        size_list = settings.SLIDER_PICTURE_CROPPING_SIZE.split('x')
        for i in range(0, len(size_list)):
            size_list[i] = int(size_list[i])
        if self.image:
            return get_thumbnailer(
                self.image
            ).get_thumbnail({
                'size': tuple(size_list),
                'box': self.cropping,
                'crop': True,
                'detail': True,
            }).url
        else:
            return ''
